@@ -1,7 +1,6 @@
 #![cfg(feature = "regex_support")]
 
 use evalexpr::*;
-use std::panic::panic_any;
 
 #[test]
 fn test_regex_functions() {
@@ -18,7 +17,7 @@ fn test_regex_functions() {
             assert_eq!(regex, "[");
             assert!(message.contains("unclosed character class"));
         },
-        v => panic_any!(v),
+        v => panic!("{:?}", v),
     };
     assert_eq!(
         eval("str::regex_replace(\"foobar\", \".*?(o+)\", \"b$1\")"),
